Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2101)

Unified Diff: third_party/WebKit/Source/core/css/cssom/CSSSkew.h

Issue 2867883003: [CSS Typed OM] Delete obsolete number and length classes from Typed OM (Closed)
Patch Set: rebase Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/css/cssom/CSSSkew.h
diff --git a/third_party/WebKit/Source/core/css/cssom/CSSSkew.h b/third_party/WebKit/Source/core/css/cssom/CSSSkew.h
index e0d0237000b370354599424f92a0748b5e501072..574b2833c8c7ff0d846e2ef211aacb6718bf2f7e 100644
--- a/third_party/WebKit/Source/core/css/cssom/CSSSkew.h
+++ b/third_party/WebKit/Source/core/css/cssom/CSSSkew.h
@@ -5,8 +5,8 @@
#ifndef CSSSkew_h
#define CSSSkew_h
-#include "core/css/cssom/CSSAngleValue.h"
#include "core/css/cssom/CSSMatrixComponent.h"
+#include "core/css/cssom/CSSNumericValue.h"
#include "core/css/cssom/CSSTransformComponent.h"
namespace blink {
@@ -16,21 +16,28 @@ class CORE_EXPORT CSSSkew final : public CSSTransformComponent {
DEFINE_WRAPPERTYPEINFO();
public:
- static CSSSkew* Create(const CSSAngleValue* ax, const CSSAngleValue* ay) {
+ static CSSSkew* Create(const CSSNumericValue* ax, const CSSNumericValue* ay) {
return new CSSSkew(ax, ay);
}
static CSSSkew* FromCSSValue(const CSSFunctionValue&);
// Bindings requires returning non-const pointers. This is safe because
- // CSSAngleValues are immutable.
- CSSAngleValue* ax() const { return const_cast<CSSAngleValue*>(ax_.Get()); }
- CSSAngleValue* ay() const { return const_cast<CSSAngleValue*>(ay_.Get()); }
+ // CSSNumericValues are immutable.
+ CSSNumericValue* ax() const {
+ return const_cast<CSSNumericValue*>(ax_.Get());
+ }
+ CSSNumericValue* ay() const {
+ return const_cast<CSSNumericValue*>(ay_.Get());
+ }
TransformComponentType GetType() const override { return kSkewType; }
CSSMatrixComponent* asMatrix() const override {
- return CSSMatrixComponent::Skew(ax_->degrees(), ay_->degrees());
+ return nullptr;
+ // TODO(meade): Reimplement this once the number/unit types
+ // are re-implemented.
+ // return CSSMatrixComponent::Skew(ax_->degrees(), ay_->degrees());
}
CSSFunctionValue* ToCSSValue() const override;
@@ -42,11 +49,11 @@ class CORE_EXPORT CSSSkew final : public CSSTransformComponent {
}
private:
- CSSSkew(const CSSAngleValue* ax, const CSSAngleValue* ay)
+ CSSSkew(const CSSNumericValue* ax, const CSSNumericValue* ay)
: CSSTransformComponent(), ax_(ax), ay_(ay) {}
- Member<const CSSAngleValue> ax_;
- Member<const CSSAngleValue> ay_;
+ Member<const CSSNumericValue> ax_;
+ Member<const CSSNumericValue> ay_;
};
} // namespace blink
« no previous file with comments | « third_party/WebKit/Source/core/css/cssom/CSSSimpleLength.idl ('k') | third_party/WebKit/Source/core/css/cssom/CSSSkew.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698